Index: utils/CI/sette_wave/README.rst
===================================================================
--- utils/CI/sette_wave/README.rst	(revision 14206)
+++ utils/CI/sette_wave/README.rst	(revision 14240)
@@ -46,7 +46,7 @@
                 
         # XIOS management
-          |  USING_XIOS        : flag to control the activation of key_iomput. 
-                                "yes" to compile using key_iomput and link to the external XIOS library.
-                                "no"  to compile without key_iomput and link to the old IOIPSL library.
+          |  USING_XIOS        : flag to control the activation of key_xios. 
+                                "yes" to compile using key_xios and link to the external XIOS library.
+                                "no"  to compile without key_xios and link to the old IOIPSL library.
           |  USING_MPMD        : flag to control the use of stand-alone IO servers 
                                 (requires USING_XIOS="yes").
Index: utils/CI/sette_wave/param.cfg
===================================================================
--- utils/CI/sette_wave/param.cfg	(revision 14206)
+++ utils/CI/sette_wave/param.cfg	(revision 14240)
@@ -41,7 +41,7 @@
 #
 # RUN set up
-# USING_XIOS        : flag to control the activation of key_iomput
-#                      "yes" to compile using key_iomput and link to the external XIOS library
-#                      "no"  to compile without key_iomput and link to the old IOIPSL library
+# USING_XIOS        : flag to control the activation of key_xios
+#                      "yes" to compile using key_xios and link to the external XIOS library
+#                      "no"  to compile without key_xios and link to the old IOIPSL library
 USING_XIOS=${SETTE_XIOS:-"yes"}
 # USING_MPMD        : flag to control the use of stand-alone IO servers
Index: utils/CI/sette_wave/OLD_SCRIPT/sette_beginner.sh
===================================================================
--- utils/CI/sette_wave/OLD_SCRIPT/sette_beginner.sh	(revision 14206)
+++ utils/CI/sette_wave/OLD_SCRIPT/sette_beginner.sh	(revision 14240)
@@ -28,7 +28,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
 # USING_XIOS        : flag to control the activation of key_iomput
 #                      "yes" to compile using key_iomput and link to the external XIOS library
 #                      "no"  to compile without key_iomput and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
@@ -93,5 +93,5 @@
 export MPIRUN_FLAG="yes"
 
-export DEL_KEYS="key_iomput"
+export DEL_KEYS="key_xios"
 if [ ${USING_XIOS} == "yes" ]
  then 
@@ -28,7 +28,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
-# USING_XIOS        : flag to control the activation of key_iomput
-#                      "yes" to compile using key_iomput and link to the external XIOS library
-#                      "no"  to compile without key_iomput and link to the old IOIPSL library
+# USING_XIOS        : flag to control the activation of key_xios
+#                      "yes" to compile using key_xios and link to the external XIOS library
+#                      "no"  to compile without key_xios and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
Index: utils/CI/sette_wave/sette_reference-configurations.sh
===================================================================
--- utils/CI/sette_wave/sette_reference-configurations.sh	(revision 14206)
+++ utils/CI/sette_wave/sette_reference-configurations.sh	(revision 14240)
@@ -29,7 +29,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
 # USING_XIOS        : flag to control the activation of key_iomput
 #                      "yes" to compile using key_iomput and link to the external XIOS library
 #                      "no"  to compile without key_iomput and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
@@ -117,7 +117,7 @@
 if [ ${USING_XIOS} == "yes" ] 
  then 
-   export ADD_KEYS="${ADD_KEYS} key_iomput"
+   export ADD_KEYS="${ADD_KEYS} key_xios"
  else
-   export DEL_KEYS="${DEL_KEYS} key_iomput"
+   export DEL_KEYS="${DEL_KEYS} key_xios"
 fi
 #
@@ -29,7 +29,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
-# USING_XIOS        : flag to control the activation of key_iomput
-#                      "yes" to compile using key_iomput and link to the external XIOS library
-#                      "no"  to compile without key_iomput and link to the old IOIPSL library
+# USING_XIOS        : flag to control the activation of key_xios
+#                      "yes" to compile using key_xios and link to the external XIOS library
+#                      "no"  to compile without key_xios and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
Index: utils/CI/sette_wave/sette_test-cases.sh
===================================================================
--- utils/CI/sette_wave/sette_test-cases.sh	(revision 14206)
+++ utils/CI/sette_wave/sette_test-cases.sh	(revision 14240)
@@ -31,7 +31,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
 # USING_XIOS        : flag to control the activation of key_iomput
 #                      "yes" to compile using key_iomput and link to the external XIOS library
 #                      "no"  to compile without key_iomput and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
@@ -114,7 +114,7 @@
 if [ ${USING_XIOS} == "yes" ] 
  then 
-   export ADD_KEYS="${ADD_KEYS} key_iomput"
+   export ADD_KEYS="${ADD_KEYS} key_xios"
  else
-   export DEL_KEYS="${DEL_KEYS} key_iomput"
+   export DEL_KEYS="${DEL_KEYS} key_xios"
 fi
 #
@@ -31,7 +31,7 @@
 # MPIRUN_FLAG       : flag to run in parallel (MPI) "yes"
 #                           to run in sequential mode (NB_PROC = 1) "no"
-# USING_XIOS        : flag to control the activation of key_iomput
-#                      "yes" to compile using key_iomput and link to the external XIOS library
-#                      "no"  to compile without key_iomput and link to the old IOIPSL library
+# USING_XIOS        : flag to control the activation of key_xios
+#                      "yes" to compile using key_xios and link to the external XIOS library
+#                      "no"  to compile without key_xios and link to the old IOIPSL library
 # USING_MPMD        : flag to control the use of stand-alone IO servers
 #                     requires USING_XIOS="yes"
